import pygame
import crashteroidsconfig

class BaseSprite(pygame.sprite.Sprite):
 def __init__(self, spriteImage):
  #default to center of screen pointing strait up
  self.orientation = 0
  self.rotatingRight = False
  self.rotatingLeft = False
  self.velocityX = 0
  self.velocityY = 0
  self.accelerating = False
  self.x = 400
  self.y = 240
  self.maxVelocity = 50
  self.accelerationDivisor = 3 #accelerate at 1/3 speed
  self.rotationRate = 15 #makes 360/14 = 24 orientations
  
  pygame.sprite.Sprite.__init__(self)
  #load the image and shave a few pixels from the rect
  self.masterImage = pygame.image.load(spriteImage)
  self.image = self.masterImage
  self.rect = self.image.get_rect()
  self.rect.height -= 5
  self.rect.width -= 5
  self.updateImage()
  
 def startRotationRight(self):
  self.rotatingRight = True

 def startRotationLeft(self):
  self.rotatingLeft = True
  
 def stopRotationRight(self):
  self.rotatingRight = False
  
 def stopRotationLeft(self):
  self.rotatingLeft = False
 
 def accelerate(self):
  self.accelerating = True
  
 def stopAcceleration(self):
  self.accelerating = False
  
 def update(self):
  #update the orientation
  if self.rotatingLeft:
   self.orientation += self.rotationRate
   if self.orientation >= 360:
    self.orientation = 0 

  if self.rotatingRight:
   self.orientation -= self.rotationRate
   if self.orientation < 0:
    self.orientation = 345
  
  #change the image if rotating
  if self.rotatingLeft or self.rotatingRight:
   self.updateImage()
  
  #adjust the velocity based on orientation
  if self.accelerating:
   num = (24 - self.orientation/15) 
   if num == 24:
    num = 0
   if num < 7:
    self.velocityX += num
    self.velocityY -= 6 - num
   elif num < 13:
    self.velocityX += 12 - num
    self.velocityY += num - 6
   elif num < 19:
    self.velocityX -= num - 12
    self.velocityY += 18 - num
   elif num < 24:
    self.velocityX -= 24 - num
    self.velocityY -= num - 18
  
  #set the velocity is within bounds
  if self.velocityX > self.maxVelocity:
   self.velocityX = self.maxVelocity
  if self.velocityY > self.maxVelocity:
   self.velocityY = self.maxVelocity
  if self.velocityX < 0 - self.maxVelocity:
   self.velocityX = 0 - self.maxVelocity
  if self.velocityY < 0 - self.maxVelocity:
   self.velocityY = 0 - self.maxVelocity
   
  #adjust the location, raise accelrationDivisor to slow down
  self.x += self.velocityX/self.accelerationDivisor
  self.y += self.velocityY/self.accelerationDivisor

  #wrap the sprite around the screen, maintain "hyper zone"
  if self.x > 800:
   self.x = 0 - self.rect.height
  if self.y > 480:
   self.y = 0 - self.rect.width
   
  if self.x < 0 - self.rect.width:
   self.x = 800
  if self.y < 0 - self.rect.height:
   self.y = 480
  
  self.rect.topleft = [self.x,self.y]
  
 def updateImage(self):
  oldCenter = self.rect.center
  self.image = pygame.transform.rotate(self.masterImage,self.orientation)
  self.rect = self.image.get_rect()
  #make a buffer so sprites can appear closer together
  self.rect.width -= 20
  self.rect.height -= 20
  self.rect.center = oldCenter
 
 def explode(self):
  self.kill()#remove self from any spritegroups by default
