import pygame, random
from baseSprite import BaseSprite
from bullet import Bullet
import crashteroidsconfig

class Guy(BaseSprite):
 def __init__(self, bulletsGroup):
  BaseSprite.__init__(self, crashteroidsconfig.guy_img)
  self.bullets = bulletsGroup
  self.hum = pygame.mixer.Sound(crashteroidsconfig.guy_eng)
  self.explosionSound = pygame.mixer.Sound(crashteroidsconfig.guy_explode)
  self.explosionSound.set_volume(.2)
  self.alive = True
  self.exploding = False
  self.explodestage = 0
  self.visible = True
  self.maxbullets = 4
  self.bigbullets = False
 
 def initPos(self):
  #start off in the center of screen, still, facing up
  self.stop()
  self.x = 400
  self.y = 240
  self.masterImage = pygame.image.load(crashteroidsconfig.guy_img)
  self.updateImage()
  self.visible = True
  self.alive = True
  
 def accelerate(self):
  if self.alive and not self.exploding:
   BaseSprite.accelerate(self)
   self.hum.play(-1)
  
 def stopAcceleration(self):
  BaseSprite.stopAcceleration(self)
  self.hum.stop()
 
 def explode(self):
  self.stop()
  if self.alive:
   self.hum.stop()
   self.explosionSound.play()
   self.alive = False
   self.exploding = True
   
 def shoot(self):
  if self.alive:
   #only allow max numbe of  bullets on the screen at a time
   if len(self.bullets.sprites()) < self.maxbullets:
    imgName = crashteroidsconfig.guy_bullet
    if self.bigbullets:
     imgName = crashteroidsconfig.guy_bullet_big
    b = Bullet(self.x,self.y,self.orientation, imgName)
    self.bullets.add(b)

 def hyperspace(self):
  self.stop()
  self.x = random.randint(0,800)
  self.y = random.randint(0,480)
  #every now and then, blow up on hyperspace for no reason
  if random.randint(0,5) == 2:
   self.explode()
   
 def stop(self):
  self.orientation = 0
  self.rotatingRight = False
  self.rotatingLeft = False
  self.velocityX = 0
  self.velocityY = 0
  self.accelerating = False
  
 def update(self):
  BaseSprite.update(self)
  if self.exploding: 
   #do an explosion image for each tick
   self.explodestage += 1
   e = self.explodestage
   if e < 8:#there are 7 explosion images
    e = str(e)
    self.masterImage = pygame.image.load(config.guy_explode_stage + e  + ".png")
    self.updateImage()
   else:#explosion is done
    self.visible = False
    self.exploding = False
